from setuptools import setup

setup(name='aka-distribution',
      version='1.1',
      description='Gaussian-Binomial distributions',
      packages=['aka-distribution'],
      author= 'Akash Salvi',
      author_email = 'akash@gmail.com',
      zip_safe=False)
